Utils — Map of Objects

Skip to main content
`Ctrl`+`K`

# Utils

get_instance_id(single, family_id, j)

  Return the instance id

is_module_loaded(module_import_name)

  Checks if a given module has already been loaded. BEWARE: the argument should be the true name of a module, not an alias. That is for > import foo as bar one should pass “foo” to this function

make_folder_if_do_not_exist(path)

  Create a folder if it does not exist

rotate(vector, shift)

  Rotate a vector